@@ -5,7 +5,7 @@
     {
         public:
             void fun();
-            string d_str;
+            std::string d_str;
     };
     inline void X::fun()
     {
@@ -13,14 +13,13 @@
     }
 
     using namespace std;
-
     int main()
     {
-        cout
-        << "size of pointer to data-member:     " << sizeof(&X::d_str) << "\n"
-        << "size of pointer to member function: " << sizeof(&X::fun) << "\n"
-        << "size of pointer to non-member data: " << sizeof(char *) << "\n"
-        << "size of pointer to free function:   " << sizeof(&printf) << endl;
+        cout <<
+           "size of pointer to data-member:     " << sizeof(&X::d_str) << "\n"
+           "size of pointer to member function: " << sizeof(&X::fun) << "\n"
+           "size of pointer to non-member data: " << sizeof(char *) << "\n"
+           "size of pointer to free function:   " << sizeof(&printf) << '\n';
     }
 
     /*
